#include <stdio.h>
#include <stdlib.h>
#include <math.h>

typedef struct _Point{
    double      x,y;
}Point;

typedef struct _Poly{
    int         n;        // ⢮ 祪
    Point       p[110];    // ᠬ 窨
}Poly;

Poly        mas[10];
Point       gp;
double      eps=1e-9;

int cmpf (const void *A,const void *B)
{
    double      l1,l2,r1,r2;
    Point       *a=(Point *)A,*b=(Point *)B;

    l1=sqrt((a->x-gp.x)*(a->x-gp.x)+(a->y-gp.y)*(a->y-gp.y));
    l2=sqrt((b->x-gp.x)*(b->x-gp.x)+(b->y-gp.y)*(b->y-gp.y));
    r1=(a->x-gp.x)/l1;
    r2=(b->x-gp.x)/l2;
    if (r1>r2)return -1;
    return 1;
}

// 室  窠  
int isin (Point a,Poly b)
{
    int             i,i1;
    double          s,r;

    r=0.0;
    for (i=0;i<b.n;i++){
        i1=(i+1)%b.n;
        s=(b.p[i].x-a.x)*(b.p[i1].y-a.y)-(b.p[i].y-a.y)*(b.p[i1].x-a.x);
        if (fabs(s)>eps){
            if (s*r<0)return 0;
            r=s;
        }
    }
    return 1;
}

// 室  祭  १, ᫨ ⠪ 
int cross (Point p1,Point p2,Point p3,Point p4,Point *res)
{
    double          a1,b1,c1,a2,b2,c2,d,x,y,t;

    a1=p1.y-p2.y;
    b1=p2.x-p1.x;
    c1=-a1*p1.x-b1*p1.y;
    a2=p3.y-p4.y;
    b2=p4.x-p3.x;
    c2=-a2*p3.x-b2*p3.y;
    d=a1*b2-b1*a2;
    if (fabs(d)<eps)return 0;   // ᫨ १ ࠫ
    x=(-c1*b2+c2*b1)/d;
    y=(-c2*a1+c1*a2)/d;
    if (fabs(p1.x-p2.x)>eps)t=(x-p2.x)/(p1.x-p2.x);
    else t=(y-p2.y)/(p1.y-p2.y);
    if (t<eps || t>1.0-eps)return 0;
    if (fabs(p3.x-p4.x)>eps)t=(x-p4.x)/(p3.x-p4.x);
    else t=(y-p4.y)/(p3.y-p4.y);
    if (t<eps || t>1.0-eps)return 0;
    res->x=x;
    res->y=y;
    return 1;
}

// 頤 㪫 䨣
double square (Poly a)
{
    int             i;
    double          s;

    if (a.n<3)return 0.0;
    s=0.0;
    for (i=1;i<a.n-1;i++){
        s+=(a.p[i].x-a.p[0].x)*(a.p[i+1].y-a.p[0].y)-
           (a.p[i].y-a.p[0].y)*(a.p[i+1].x-a.p[0].x);
    }
    if (s<0)s=-s;
    return s/2.0;
}

// 室 祭  㣮쭨
void intersect (Poly a,Poly b,Poly *res)
{
    int             i,j,id,k;
    Poly            r;

    if (a.n<3 || b.n<3){
        res->n=0;
        return;
    }
    r.n=0;
    for (i=0;i<a.n;i++)
        if (isin(a.p[i],b))r.p[r.n++]=a.p[i];
    for (i=0;i<b.n;i++)
        if (isin(b.p[i],a))r.p[r.n++]=b.p[i];
    for (i=0;i<a.n;i++){
        for (j=0;j<b.n;j++){
            if (cross(a.p[i],a.p[(i+1)%a.n],b.p[j],b.p[(j+1)%b.n],&r.p[r.n]))
                r.n++;
        }
    }
    // 㡨ࠥ 騥 設
    k=1;
    for (i=1;i<r.n;i++){
        for (j=0;j<k && (fabs(r.p[j].x-r.p[i].x)>eps || fabs(r.p[j].y-r.p[i].y)>eps);j++);
        if (j==k)r.p[k++]=r.p[i];
    }
    r.n=k;
    if (r.n<3){
        res->n=0;
        return;
    }

    // 롥६ ᠬ -ࠢ 
    id=0;
    for (i=1;i<r.n;i++){
        if (r.p[i].y<r.p[id].y || (r.p[i].y==r.p[id].y && r.p[i].x>r.p[id].x)){
            id=i;
        }
    }
    // 㯮冷稬 設  浪  室
    gp=r.p[id];
    r.p[id]=r.p[0];
    r.p[0]=gp;
    qsort (r.p+1,r.n-1,sizeof (Point),cmpf);
    *res=r;
}

int main (void)
{
    int             i,j,n,f,best;
    Poly            r;
    double          s,mx;

    freopen ("input.txt","rt",stdin);
    freopen ("output.txt","wt",stdout);
    scanf ("%d",&n);
    
    // 뢠 
    for (i=0;i<n;i++){
        scanf ("%d",&mas[i].n);
        for (j=0;j<mas[i].n;j++)scanf ("%lf %lf",&mas[i].p[j].x,&mas[i].p[j].y);
    }

    best=0;
    mx=0;
    // ॡࠥ ᥢ ਠ
    for (i=1;i<1<<n;i++){
        f=0;
        for (j=0;j<n;j++){
            if (i&(1<<j)){
               if (!f)r=mas[j];
               else intersect (r,mas[j],&r);
               f++;
            }
        }
        s=square (r);
        if (s>eps && best<f){
            best=f;
            mx=s;
        }
        else if (s>eps && best==f){
            best=f;
            mx+=s;
        }
    }
    printf ("%.3lf\n",mx);

    return 0;
}
